/* gdict.h - convenience header for libgdict
 *
 * Copyright (C) 2005  Emmanuele Bassi <ebassi@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 */

#ifndef __GDICT_H__
#define __GDICT_H__

#include <libgdict/gdict-context.h>
#include <libgdict/gdict-client-context.h>
#include <libgdict/gdict-source.h>
#include <libgdict/gdict-source-loader.h>
#include <libgdict/gdict-database-chooser.h>
#include <libgdict/gdict-defbox.h>
#include <libgdict/gdict-speller.h>
#include <libgdict/gdict-strategy-chooser.h>
#include <libgdict/gdict-utils.h>
#include <libgdict/gdict-enum-types.h>
#include <libgdict/gdict-version.h>

#endif /* __GDICT_H__ */
